#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.3
visibility:           public
id:                   distributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
key:                  distributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  aaadca9a2995e0aa60ebddad7b13a746
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/distributive-0.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/distributive-0.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/distributive-0.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
depends:
    base-4.18.2.1 tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

